@@ -13,7 +13,7 @@ extern "C" {
 
 
 /** Defines the Baresip version string */
-#define BARESIP_VERSION "3.9.0"
+#define BARESIP_VERSION "3.10.0"
 
 
 #ifndef NET_MAX_NS
@@ -79,6 +79,12 @@ enum jbuf_type {
 	JBUF_ADAPTIVE
 };
 
+/** Defines the incoming out-of-dialog request mode */
+enum inreq_mode {
+	INREQ_MODE_OFF = 0,
+	INREQ_MODE_ON,
+};
+
 struct account;
 
 int account_alloc(struct account **accp, const char *sipaddr);
@@ -92,6 +98,7 @@ int account_set_sipnat(struct account *acc, const char *sipnat);
 int account_set_answermode(struct account *acc, enum answermode mode);
 int account_set_rel100_mode(struct account *acc, enum rel100_mode mode);
 int account_set_dtmfmode(struct account *acc, enum dtmfmode mode);
+int account_set_inreq_mode(struct account *acc, enum inreq_mode mode);
 int account_set_display_name(struct account *acc, const char *dname);
 int account_set_regint(struct account *acc, uint32_t regint);
 int account_set_stun_uri(struct account *acc, const char *uri);
@@ -120,6 +127,7 @@ uint32_t account_prio(const struct account *acc);
 enum answermode account_answermode(const struct account *acc);
 enum rel100_mode account_rel100_mode(const struct account *acc);
 enum dtmfmode account_dtmfmode(const struct account *acc);
+enum inreq_mode account_inreq_mode(const struct account *acc);
 const char *account_display_name(const struct account *acc);
 const char *account_aor(const struct account *acc);
 const char *account_auth_user(const struct account *acc);
@@ -153,6 +161,7 @@ void account_set_autelev_pt(struct account *acc, uint32_t pt);
 uint32_t account_autelev_pt(struct account *acc);
 const char* account_uas_user(const struct account *acc);
 const char* account_uas_pass(const struct account *acc);
+bool account_uas_isset(const struct account *acc);
 
 /*
  * Call
@@ -257,6 +266,7 @@ void call_set_current(struct list *calls, struct call *call);
 const struct list *call_get_custom_hdrs(const struct call *call);
 void call_set_media_direction(struct call *call, enum sdp_dir a,
 			     enum sdp_dir v);
+void call_set_mdir(struct call *call, enum sdp_dir a, enum sdp_dir v);
 void call_set_media_estdir(struct call *call, enum sdp_dir a, enum sdp_dir v);
 void call_start_answtmr(struct call *call, uint32_t ms);
 bool          call_supported(struct call *call, uint16_t tags);
@@ -348,6 +358,7 @@ struct config_sip {
 	uint32_t transports;    /**< Supported transports mask      */
 	enum sip_transp transp; /**< Default outgoing SIP transport protocol */
 	bool verify_server;     /**< Enable SIP TLS verify server   */
+	bool verify_client;     /**< Enable SIP TLS verify client   */
 	uint8_t tos;            /**< Type-of-Service for SIP        */
 };
 
@@ -926,6 +937,7 @@ int ua_raise(struct ua *ua);
 int ua_set_autoanswer_value(struct ua *ua, const char *value);
 void ua_add_extension(struct ua *ua, const char *extension);
 void ua_remove_extension(struct ua *ua, const char *extension);
+bool ua_req_allowed(const struct ua *ua, const struct sip_msg *msg);
 
 
 /* One instance */
@@ -1420,6 +1432,7 @@ int   video_debug(struct re_printf *pf, const struct video *v);
 struct stream *video_strm(const struct video *v);
 const struct vidcodec *video_codec(const struct video *vid, bool tx);
 void video_sdp_attr_decode(struct video *v);
+void video_req_keyframe(struct video *vid);
 
 double video_calc_seconds(uint64_t rtp_ts);
 double video_timestamp_to_seconds(uint64_t timestamp);
